birdears.interfaces package
===========================

.. automodule:: birdears.interfaces
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

birdears.interfaces.commandline module
--------------------------------------

.. automodule:: birdears.interfaces.commandline
   :members:
   :undoc-members:
   :show-inheritance:

birdears.interfaces.urwid module
--------------------------------

.. automodule:: birdears.interfaces.urwid
   :members:
   :undoc-members:
   :show-inheritance:
